@@ -8,28 +8,35 @@
 import logging
 from .util import Singleton
 
-from math import sqrt
+import numpy as np
 
 from . import glass
 
 
-class OharaCatalog(glass.GlassCatalog, metaclass=Singleton):
+class OharaCatalog(glass.GlassCatalogXLSX, metaclass=Singleton):
     #    data_header = 1
     #    data_start = 2
     #    num_glasses = 134
     #    name_col_offset = 1
     #    coef_col_offset = 60
     #    index_col_offset = 4
-    nline_str = {'nC': 'nC',
-                 'nd': 'nd',
-                 'ne': 'ne',
-                 'nF': 'nF',
-                 'ng': 'ng',
-                 'nh': 'nh',
-                 'ni': 'ni'}
+    nline_str = {'t': 'nt',
+                 's': 'ns',
+                 'r': 'nr',
+                 'C': 'nC',
+                 "C'": "nC'",
+                 'D': 'nD',
+                 'd': 'nd',
+                 'e': 'ne',
+                 'F': 'nF',
+                 "F'": "nF'",
+                 'g': 'ng',
+                 'h': 'nh',
+                 'i': 'ni'}
 
     def __init__(self, fname='OHARA.xlsx'):
-        super().__init__('Ohara', fname, 'Glass ', 'A1', 'n2325')
+        super().__init__('Ohara', fname, 'Glass ', 'A1', 'n2325',
+                         transmission_offset=81, num_wvls=32)
 
     def create_glass(self, gname, gcat):
         return OharaGlass(gname)
@@ -49,8 +56,8 @@ class OharaGlass(glass.Glass):
     def calc_rindex(self, wv_nm):
         wv = 0.001*wv_nm
         wv2 = wv*wv
-        coefs = self.catalog.glass_coefs(self.gindex)
+        coefs = self.coefs
         n2 = 1 + coefs[0]*wv2/(wv2 - coefs[3])
         n2 += coefs[1]*wv2/(wv2 - coefs[4])
         n2 += coefs[2]*wv2/(wv2 - coefs[5])
-        return sqrt(n2)
+        return np.sqrt(n2)
