@@ -8,32 +8,43 @@
 import logging
 from .util import Singleton
 
-from math import sqrt
+import numpy as np
 
 from . import glass
 
 
-class SchottCatalog(glass.GlassCatalog, metaclass=Singleton):
+class SchottCatalog(glass.GlassCatalogXLS, metaclass=Singleton):
     #    data_header = 3
     #    data_start = 4
     #    num_glasses = 123
     #    name_col_offset = 0
     #    coef_col_offset = 6
     #    index_col_offset = 117
-    nline_str = {'nC': '  nC',
-                 'nd': '  nd',
-                 'ne': '  ne',
-                 'nF': '  nF',
-                 'ng': '  ng',
-                 'nh': '  nh',
-                 'ni': '  ni'}
+    nline_str = {'t': '  nt',
+                 's': '  ns',
+                 'r': '  nr',
+                 'C': '  nC',
+                 "C'": "  nC'",
+                 'D': '  nD',
+                 'd': '  nd',
+                 'e': '  ne',
+                 'F': '  nF',
+                 "F'": "  nF'",
+                 'g': '  ng',
+                 'h': '  nh',
+                 'i': '  ni'}
 
     def __init__(self, fname='SCHOTT.xls'):
-        super().__init__('Schott', fname, 'Glass', 'B1', '  n2325.4')
+        super().__init__('Schott', fname, 'Glass', 'B1', '  n2325.4',
+                         transmission_offset=67, num_wvls=30)
 
     def create_glass(self, gname, gcat):
         return SchottGlass(gname)
 
+    def get_transmission_wvl(self, header_str):
+        """Returns the wavelength value from the transmission data header string."""
+        return float(header_str[len('TAUI10/'):])
+
 
 class SchottGlass(glass.Glass):
     catalog = SchottCatalog()
@@ -49,8 +60,8 @@ class SchottGlass(glass.Glass):
     def calc_rindex(self, wv_nm):
         wv = 0.001*wv_nm
         wv2 = wv*wv
-        coefs = self.catalog.glass_coefs(self.gindex)
+        coefs = self.coefs
         n2 = 1. + coefs[0]*wv2/(wv2 - coefs[3])
         n2 = n2 + coefs[1]*wv2/(wv2 - coefs[4])
         n2 = n2 + coefs[2]*wv2/(wv2 - coefs[5])
-        return sqrt(n2)
+        return np.sqrt(n2)
